ardt.datasets.dreamer.DreamerDataset
====================================

.. currentmodule:: ardt.datasets.dreamer

.. autoclass:: DreamerDataset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DreamerDataset.__init__
      ~DreamerDataset.get_balanced_dataset
      ~DreamerDataset.get_dataset_splits
      ~DreamerDataset.get_interleaved_trial_dataset
      ~DreamerDataset.get_media_name_by_movie_id
      ~DreamerDataset.get_signal_metadata
      ~DreamerDataset.get_trial_splits
      ~DreamerDataset.get_working_dir
      ~DreamerDataset.get_working_path
      ~DreamerDataset.load_trials
      ~DreamerDataset.preload
      ~DreamerDataset.set_signal_metadata
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DreamerDataset.expected_media_responses
      ~DreamerDataset.media_file_offset
      ~DreamerDataset.media_ids
      ~DreamerDataset.media_offset
      ~DreamerDataset.native_media_ids
      ~DreamerDataset.native_participant_ids
      ~DreamerDataset.participant_ids
      ~DreamerDataset.participant_offset
      ~DreamerDataset.signal_preprocessors
      ~DreamerDataset.signals
      ~DreamerDataset.trials
   
   